@@ -1,26 +1,8 @@
-/* This file is part of Zanshin
-
-   Copyright 2015 Mario Bensi <mbensi@ipsquad.net>
-   Copyright 2017 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2015 Mario Bensi <mbensi@ipsquad.net>
+ * SPDX-FileCopyrightText: 2017 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "akonadicachingstorage.h"
@@ -61,7 +43,8 @@ public:
             QTimer::singleShot(0, this, &CachingCollectionFetchJob::retrieveFromCache);
         } else {
             auto job = m_storage->fetchCollections(Akonadi::Collection::root(),
-                                                   Akonadi::StorageInterface::Recursive);
+                                                   Akonadi::StorageInterface::Recursive,
+                                                   this);
             job->setResource(m_resource);
             addSubjob(job->kjob());
         }
@@ -177,7 +160,7 @@ public:
         if (m_cache->isCollectionPopulated(m_collection.id())) {
             QTimer::singleShot(0, this, &CachingCollectionItemsFetchJob::retrieveFromCache);
         } else {
-            auto job = m_storage->fetchItems(m_collection);
+            auto job = m_storage->fetchItems(m_collection, this);
             addSubjob(job->kjob());
         }
 
@@ -251,7 +234,7 @@ public:
                 retrieveFromCache(item);
             });
         } else {
-            auto job = m_storage->fetchItem(m_item);
+            auto job = m_storage->fetchItem(m_item, this);
             job->setCollection(m_collection);
             addSubjob(job->kjob());
         }
@@ -323,9 +306,9 @@ KJob *CachingStorage::updateItem(Item item, QObject *parent)
     return m_storage->updateItem(item, parent);
 }
 
-KJob *CachingStorage::removeItem(Item item)
+KJob *CachingStorage::removeItem(Item item, QObject *parent)
 {
-    return m_storage->removeItem(item);
+    return m_storage->removeItem(item, parent);
 }
 
 KJob *CachingStorage::removeItems(Item::List items, QObject *parent)
@@ -358,24 +341,24 @@ KJob *CachingStorage::removeCollection(Collection collection, QObject *parent)
     return m_storage->removeCollection(collection, parent);
 }
 
-KJob *CachingStorage::createTransaction()
+KJob *CachingStorage::createTransaction(QObject *parent)
 {
-    return m_storage->createTransaction();
+    return m_storage->createTransaction(parent);
 }
 
-CollectionFetchJobInterface *CachingStorage::fetchCollections(Collection collection, StorageInterface::FetchDepth depth)
+CollectionFetchJobInterface *CachingStorage::fetchCollections(Collection collection, StorageInterface::FetchDepth depth, QObject *parent)
 {
-    return new CachingCollectionFetchJob(m_storage, m_cache, collection, depth);
+    return new CachingCollectionFetchJob(m_storage, m_cache, collection, depth, parent);
 }
 
-ItemFetchJobInterface *CachingStorage::fetchItems(Collection collection)
+ItemFetchJobInterface *CachingStorage::fetchItems(Collection collection, QObject *parent)
 {
-    return new CachingCollectionItemsFetchJob(m_storage, m_cache, collection);
+    return new CachingCollectionItemsFetchJob(m_storage, m_cache, collection, parent);
 }
 
-ItemFetchJobInterface *CachingStorage::fetchItem(Akonadi::Item item)
+ItemFetchJobInterface *CachingStorage::fetchItem(Akonadi::Item item, QObject *parent)
 {
-    return new CachingSingleItemFetchJob(m_storage, m_cache, item);
+    return new CachingSingleItemFetchJob(m_storage, m_cache, item, parent);
 }
 
 #include "akonadicachingstorage.moc"
